export declare function setLockManager(lockManager: LockManager): void;
export declare function lockManager(): LockManager;
/**
 * A lock manager
 */
export interface LockManager {
    /**
     * Obtain a lock over a shared resource.
     *
     * Will block until the lock becomes available.
     *
     * Will call onLockFailure if the lock is not available within the built in timeout
     *
     * @param id
     * @param onLock
     * @param onLockFailure
     */
    withLock: <T>(id: string, onLock: () => Promise<T>, onLockFailure: () => void) => Promise<T>;
    /**
     * Obtain a lock over a shared resource.
     *
     * If the lock is not immediately available, will call onLockFailure and terminate
     *
     * @param id
     * @param onLock
     * @param onLockFailure
     */
    tryLock: <T>(id: string, onLock: () => Promise<T>, onLockFailure: () => void) => Promise<T>;
}
export declare function hashCode(str: string): number;
